@@ -1,7 +1,7 @@
 /*
  * This file is part of Amtk - Actions, Menus and Toolbars Kit
  *
- * Copyright 2017, 2018 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright 2017, 2018, 2020 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * Amtk is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
@@ -240,12 +240,7 @@ amtk_factory_set_property (GObject      *object,
 	{
 		case PROP_APPLICATION:
 			g_assert (factory->priv->app == NULL);
-			factory->priv->app = g_value_get_object (value);
-			if (factory->priv->app != NULL)
-			{
-				g_object_add_weak_pointer (G_OBJECT (factory->priv->app),
-							   (gpointer *) &factory->priv->app);
-			}
+			g_set_weak_pointer (&factory->priv->app, g_value_get_object (value));
 			break;
 
 		case PROP_DEFAULT_FLAGS:
@@ -263,12 +258,7 @@ amtk_factory_dispose (GObject *object)
 {
 	AmtkFactory *factory = AMTK_FACTORY (object);
 
-	if (factory->priv->app != NULL)
-	{
-		g_object_remove_weak_pointer (G_OBJECT (factory->priv->app),
-					      (gpointer *) &factory->priv->app);
-		factory->priv->app = NULL;
-	}
+	g_clear_weak_pointer (&factory->priv->app);
 
 	G_OBJECT_CLASS (amtk_factory_parent_class)->dispose (object);
 }
@@ -464,7 +454,7 @@ common_create_widget (AmtkFactory       *factory,
 
 	if ((flags & AMTK_FACTORY_IGNORE_GACTION) == 0)
 	{
-		gtk_actionable_set_action_name (GTK_ACTIONABLE (*widget), action_name);
+		gtk_actionable_set_detailed_action_name (GTK_ACTIONABLE (*widget), action_name);
 	}
 
 	return action_info;
